using Microsoft.AspNetCore.Mvc;
using TrainingSvc.DTOs;
using TrainingSvc.IServices;

namespace TrainingSvc.Controllers;

[ApiController]
[Route("api/training/[controller]")]
public class ExercicesController : ControllerBase
{
    private readonly IExerciceService _exerciceService;

    public ExercicesController(IExerciceService exerciceService)
    {
        _exerciceService = exerciceService;
    }

    [HttpGet]
    public async Task<ActionResult<IEnumerable<ExerciceDto>>> GetAll()
    {
        var list = await _exerciceService.GetAllAsync();
        return Ok(list);
    }

    [HttpGet("{id}")]
    public async Task<ActionResult<ExerciceDto>> GetById(string id)
    {
        var dto = await _exerciceService.GetByIdAsync(id);
        if (dto == null) return NotFound();
        return Ok(dto);
    }

    [HttpPost]
    public async Task<ActionResult<ExerciceDto>> Create([FromBody] CreateExerciceInstanceDto dto)
    {
        var created = await _exerciceService.CreateAsync(dto);
        return CreatedAtAction(nameof(GetById), new { id = created.Id }, created);
    }

    [HttpPut("{id}")]
    public async Task<IActionResult> Update(string id, [FromBody] UpdateExerciceInstanceDto dto)
    {
        var success = await _exerciceService.UpdateAsync(id, dto);
        if (!success) return NotFound();
        return NoContent();
    }

    [HttpDelete("{id}")]
    public async Task<IActionResult> Delete(string id)
    {
        var success = await _exerciceService.DeleteAsync(id);
        if (!success) return NotFound();
        return NoContent();
    }
}