using Microsoft.AspNetCore.Mvc;
using TrainingSvc.DTOs;
using TrainingSvc.IServices;

namespace TrainingSvc.Controllers;

[ApiController]
[Route("api/training/[controller]")]
public class SessionsController : ControllerBase
{
    private readonly ISessionService _sessionService;

    public SessionsController(ISessionService sessionService)
    {
        _sessionService = sessionService;
    }

    [HttpGet]
    public async Task<ActionResult<IEnumerable<SessionDto>>> GetAll()
    {
        var list = await _sessionService.GetAllAsync();
        return Ok(list);
    }

    [HttpGet("{id}")]
    public async Task<ActionResult<SessionDto>> GetById(string id)
    {
        var dto = await _sessionService.GetByIdAsync(id);
        if (dto == null) return NotFound();
        return Ok(dto);
    }

    [HttpPost]
    public async Task<ActionResult<SessionDto>> Create([FromBody] CreateSessionDto dto)
    {
        var created = await _sessionService.CreateAsync(dto);
        return CreatedAtAction(nameof(GetById), new { id = created.Id }, created);
    }

    [HttpPut("{id}")]
    public async Task<IActionResult> Update(string id, [FromBody] UpdateSessionDto dto)
    {
        var success = await _sessionService.UpdateAsync(id, dto);
        if (!success) return NotFound();
        return NoContent();
    }

    [HttpDelete("{id}")]
    public async Task<IActionResult> Delete(string id)
    {
        var success = await _sessionService.DeleteAsync(id);
        if (!success) return NotFound();
        return NoContent();
    }
}