using TrainingSvc.Data;
using Microsoft.EntityFrameworkCore;
using TrainingSvc.IServices;
using TrainingSvc.Repositories;
using TrainingSvc.Services;

var builder = WebApplication.CreateBuilder(args);

// Pour chaque repository
builder.Services.AddScoped<IExerciceTemplateRepository, ExerciceTemplateRepository>();
builder.Services.AddScoped<IExerciceInstanceRepository, ExerciceInstanceRepository>();
builder.Services.AddScoped<IExerciceService, ExerciceService>();
builder.Services.AddScoped<ISessionRepository, SessionRepository>();
builder.Services.AddScoped<ISessionService, SessionService>();
builder.Services.AddScoped<ITrainingProgramRepository, TrainingProgramRepository>();
builder.Services.AddScoped<ITrainingProgramService, TrainingProgramService>();

// Add services to the container.
builder.Services.AddControllers()
    .AddJsonOptions(options =>
    {
        options.JsonSerializerOptions.Converters.Add(new System.Text.Json.Serialization.JsonStringEnumConverter(System.Text.Json.JsonNamingPolicy.CamelCase, allowIntegerValues: false));
    });

builder.Services.AddDbContext<TrainingDbContext>(opt =>
{
    opt.UseNpgsql(builder.Configuration.GetConnectionString("TrainingDb"));

});
builder.Services.AddAutoMapper(AppDomain.CurrentDomain.GetAssemblies());


var app = builder.Build();

app.UseAuthorization();

app.MapControllers();

try
{
    TrainingDbInitializer.InitDb(app);
}
catch (Exception e)
{
    Console.WriteLine(e);
}

app.Run();


