using Microsoft.EntityFrameworkCore;
using TrainingSvc.Data;
using TrainingSvc.Entities;

namespace TrainingSvc.Repositories;

public class SessionRepository : GenericRepository<Session>, ISessionRepository
{
    public SessionRepository(TrainingDbContext context) : base(context)
    {
    }
    
    public async Task<IEnumerable<Session>> GetAllWithExercicesAndTemplatesAsync()
    {
        return await context.Sessions
            .Include(s => s.Exercices)
            .ThenInclude(e => e.ExerciceTemplate)
            .ToListAsync();
    }
    
    public async Task<Session?> GetByIdWithExercicesAndTemplatesAsync(string id)
    {
        return await context.Sessions
            .Include(s => s.Exercices)
            .ThenInclude(e => e.ExerciceTemplate)
            .FirstOrDefaultAsync(s => s.Id == id);
    }
}