using Microsoft.EntityFrameworkCore;
using TrainingSvc.Data;
using TrainingSvc.Entities;

namespace TrainingSvc.Repositories;

public class TrainingProgramRepository : GenericRepository<TrainingProgram>, ITrainingProgramRepository
{
    public TrainingProgramRepository(TrainingDbContext context) : base(context)
    {
    }
    
    public async Task<IEnumerable<TrainingProgram>> GetAllWithSessionsAsync()
    {
        return await context.TrainingPrograms
            .Include(tp => tp.Sessions)
            .ThenInclude(s => s.Exercices)
            .ThenInclude(e => e.ExerciceTemplate)
            .ToListAsync();
    }
    
    public async Task<TrainingProgram?> GetByIdWithSessionsAsync(string id)
    {
        return await context.TrainingPrograms
            .Include(tp => tp.Sessions)
            .ThenInclude(s => s.Exercices)
            .ThenInclude(e => e.ExerciceTemplate)
            .FirstOrDefaultAsync(tp => tp.Id == id);
    }
}