using AutoMapper;
using TrainingSvc.DTOs;
using TrainingSvc.Entities;
using TrainingSvc.Repositories;
using TrainingSvc.IServices;

namespace TrainingSvc.Services;

public class ExerciceService : IExerciceService
{
    private readonly IExerciceInstanceRepository _exerciceRepo;
    private readonly IExerciceTemplateRepository _exerciceTemplateRepo;
    private readonly IMapper _mapper;

    public ExerciceService(
        IExerciceInstanceRepository exerciceRepo,
        IExerciceTemplateRepository exerciceTemplateRepo,
        IMapper mapper)
    {
        _exerciceRepo = exerciceRepo;
        _exerciceTemplateRepo = exerciceTemplateRepo;
        _mapper = mapper;
    }

    public async Task<IEnumerable<ExerciceDto>> GetAllAsync()
    {
        var list = await _exerciceRepo.GetAllAsync(null, default, e => e.ExerciceTemplate);
        return _mapper.Map<IEnumerable<ExerciceDto>>(list);
    }

    public async Task<ExerciceDto?> GetByIdAsync(string id)
    {
        var entity = await _exerciceRepo.GetByIdAsync(id, e => e.ExerciceTemplate);
        return entity == null ? null : _mapper.Map<ExerciceDto>(entity);
    }

    public async Task<ExerciceDto> CreateAsync(CreateExerciceInstanceDto dto)
    {
        if (!string.IsNullOrEmpty(dto.ExerciceTemplateId))
        {
            var exists = await _exerciceTemplateRepo.ExistsAsync(t => t.Id == dto.ExerciceTemplateId);
            if (!exists)
                throw new ArgumentException("ExerciceTemplateId invalide.");
        }

        var entity = _mapper.Map<ExerciceInstance>(dto);
        await _exerciceRepo.InsertAsync(entity);
        await _exerciceRepo.SaveChangesAsync(); // Persiste en base

        return _mapper.Map<ExerciceDto>(entity);
    }

    public async Task<bool> UpdateAsync(string id, UpdateExerciceInstanceDto dto)
    {
        var entity = await _exerciceRepo.GetByIdAsync(id, e => e.ExerciceTemplate);
        if (entity == null) return false;

        _mapper.Map(dto, entity);
        _exerciceRepo.Update(entity);
        await _exerciceRepo.SaveChangesAsync(); // Persiste en base
        return true;
    }

    public async Task<bool> DeleteAsync(string id)
    {
        var entity = await _exerciceRepo.GetByIdAsync(id);
        if (entity == null) return false;
        _exerciceRepo.Delete(id);
        await _exerciceRepo.SaveChangesAsync(); // Persiste en base
        return true;
    }
}